
/* Generated data (by glib-mkenums) */

#ifndef GC_ENUMTYPES_H_
#define GC_ENUMTYPES_H_

#include <glib-object.h>

G_BEGIN_DECLS

/* enumerations from "./gc.h" */
GType gc_category_get_type (void) G_GNUC_CONST;
#define GC_TYPE_CATEGORY (gc_category_get_type ())
GType gc_search_error_get_type (void) G_GNUC_CONST;
#define GC_TYPE_SEARCH_ERROR (gc_search_error_get_type ())
GType gc_search_flag_get_type (void) G_GNUC_CONST;
#define GC_TYPE_SEARCH_FLAG (gc_search_flag_get_type ())
G_END_DECLS

#endif /* GC_ENUMTYPES_H_ */

/* Generated data ends here */

