
/* Generated data (by glib-mkenums) */

#include "gc.h"
/* enumerations from "./gc.h" */
GType
gc_category_get_type (void)
{
    static GType etype = 0;
    if (G_UNLIKELY(etype == 0)) {
        static const GEnumValue values[] = {
            { GC_CATEGORY_NONE, "GC_CATEGORY_NONE", "none" },
            { GC_CATEGORY_LETTER, "GC_CATEGORY_LETTER", "letter" },
            { GC_CATEGORY_LETTER_PUNCTUATION, "GC_CATEGORY_LETTER_PUNCTUATION", "letter-punctuation" },
            { GC_CATEGORY_LETTER_ARROW, "GC_CATEGORY_LETTER_ARROW", "letter-arrow" },
            { GC_CATEGORY_LETTER_BULLET, "GC_CATEGORY_LETTER_BULLET", "letter-bullet" },
            { GC_CATEGORY_LETTER_PICTURE, "GC_CATEGORY_LETTER_PICTURE", "letter-picture" },
            { GC_CATEGORY_LETTER_CURRENCY, "GC_CATEGORY_LETTER_CURRENCY", "letter-currency" },
            { GC_CATEGORY_LETTER_MATH, "GC_CATEGORY_LETTER_MATH", "letter-math" },
            { GC_CATEGORY_LETTER_LATIN, "GC_CATEGORY_LETTER_LATIN", "letter-latin" },
            { GC_CATEGORY_EMOJI, "GC_CATEGORY_EMOJI", "emoji" },
            { GC_CATEGORY_EMOJI_SMILEYS, "GC_CATEGORY_EMOJI_SMILEYS", "emoji-smileys" },
            { GC_CATEGORY_EMOJI_ANIMALS, "GC_CATEGORY_EMOJI_ANIMALS", "emoji-animals" },
            { GC_CATEGORY_EMOJI_FOOD, "GC_CATEGORY_EMOJI_FOOD", "emoji-food" },
            { GC_CATEGORY_EMOJI_ACTIVITIES, "GC_CATEGORY_EMOJI_ACTIVITIES", "emoji-activities" },
            { GC_CATEGORY_EMOJI_TRAVEL, "GC_CATEGORY_EMOJI_TRAVEL", "emoji-travel" },
            { GC_CATEGORY_EMOJI_OBJECTS, "GC_CATEGORY_EMOJI_OBJECTS", "emoji-objects" },
            { GC_CATEGORY_EMOJI_SYMBOLS, "GC_CATEGORY_EMOJI_SYMBOLS", "emoji-symbols" },
            { GC_CATEGORY_EMOJI_FLAGS, "GC_CATEGORY_EMOJI_FLAGS", "emoji-flags" },
            { 0, NULL, NULL }
        };
        etype = g_enum_register_static (g_intern_static_string ("GcCategory"), values);
    }
    return etype;
}
GType
gc_search_error_get_type (void)
{
    static GType etype = 0;
    if (G_UNLIKELY(etype == 0)) {
        static const GEnumValue values[] = {
            { GC_SEARCH_ERROR_FAILED, "GC_SEARCH_ERROR_FAILED", "failed" },
            { GC_SEARCH_ERROR_INVALID_STATE, "GC_SEARCH_ERROR_INVALID_STATE", "invalid-state" },
            { 0, NULL, NULL }
        };
        etype = g_enum_register_static (g_intern_static_string ("GcSearchError"), values);
    }
    return etype;
}
GType
gc_search_flag_get_type (void)
{
    static GType etype = 0;
    if (G_UNLIKELY(etype == 0)) {
        static const GFlagsValue values[] = {
            { GC_SEARCH_FLAG_NONE, "GC_SEARCH_FLAG_NONE", "none" },
            { GC_SEARCH_FLAG_WORD, "GC_SEARCH_FLAG_WORD", "word" },
            { 0, NULL, NULL }
        };
        etype = g_flags_register_static (g_intern_static_string ("GcSearchFlag"), values);
    }
    return etype;
}


/* Generated data ends here */

